@@ -1,17 +1,12 @@
 import os
-import sys
 
 from python_agent.packages import urllib3
 from python_agent.packages.urllib3.exceptions import InsecureRequestWarning
-
-if sys.version_info < (2, 7):
-    from python_agent.packages.dictconfig import dictConfig
-else:
-    from logging.config import dictConfig
+from logging.config import dictConfig
 
 urllib3.disable_warnings(InsecureRequestWarning)
 
-__version__ = "0.2.247"
+__version__ = "1.0.5"
 __package_name__ = "sealights-python-agent"
 
 
