@@ -42,8 +42,10 @@ class ConfigData(object):
         self.covReport = None
         self.perTest = True
         self.interval = constants.INTERVAL_IN_MILLISECONDS
+        self.intervalSeconds = constants.INTERVAL_IN_SECONDS
         self.testSelection = {"enable":True, "interval":constants.TEST_RECOMMENDATION.interval_sec, "timeout":constants.TEST_RECOMMENDATION.timeout_sec}
         self.test_selection_enable = True
+        self.isDisabled = False
 
     def apply_scm_args(self, scm_args):
         """
@@ -64,3 +66,7 @@ class ConfigData(object):
 
     def __str__(self):
         return 'ConfigData:\n' + to_str_obj(self)
+
+    def __eq__(self, other):
+        return self.__dict__ == other.__dict__
+
