@@ -171,7 +171,7 @@ class BackendProxy(object):
                 timeout_sec -= interval_sec
                 log.debug("Failed to receive test recommendations. remain %d retry" % (timeout_sec / interval_sec))
             else:
-                log.warn("did not get test recommendations after %d tries and %d seconds" % (n_retry, timeout_sec))
+                log.warning("did not get test recommendations after %d tries and %d seconds" % (n_retry, timeout_sec))
                 return test_recommendations
         else:
             log.warning("Test recommendations disabled")
