@@ -1,11 +1,11 @@
 "Usage: unparse.py <path to source file>"
 from __future__ import print_function, unicode_literals
-import six
+from python_agent.packages import six
 import sys
 import ast
 import os
 import tokenize
-from six import StringIO
+from python_agent.packages.six import StringIO
 
 # Large float and imaginary literals get turned into infinities in the AST.
 # We unparse those infinities to INFSTR.
