@@ -2,6 +2,7 @@ import os
 import sys
 import logging
 from python_agent.test_listener.executors.test_frameworks.agent_execution import AgentExecution
+from python_agent.utils import disableable
 
 log = logging.getLogger(__name__)
 
@@ -16,9 +17,14 @@ class NoseAgentExecution(AgentExecution):
         sys.path.insert(0, os.getcwd())
         try:
             import nose
-            from python_agent.test_listener.integrations.nose_helper import SealightsNosePlugin
             # first arg is ignored on parsing because it's the program name
             self.args.insert(0, "")
-            nose.main(addplugins=[SealightsNosePlugin()], argv=self.args)
+            addplugins = self.add_sealights_plugin() or []
+            nose.main(addplugins=addplugins, argv=self.args)
         except ImportError as e:
             log.exception("Failed importing nose. Error: %s" % str(e))
+
+    @disableable(fail_silently=True)
+    def add_sealights_plugin(self):
+        from python_agent.test_listener.integrations.nose_helper import SealightsNosePlugin
+        return [SealightsNosePlugin()]
