@@ -1,18 +1,12 @@
 import logging
-import threading
-
 import os
+import threading
+from coverage import Coverage
 
 import python_agent
 from python_agent.common import constants
-from python_agent.test_listener.line_footprints_collector import LineFootprintsCollector
 from python_agent.test_listener.method_footprints_collector import MethodFootprintsCollector
 
-try:
-    from coverage import Coverage, CoverageData
-except ImportError:
-    from coverage import coverage as Coverage
-
 log = logging.getLogger(__name__)
 
 
@@ -33,19 +27,19 @@ class CodeCoverageManager(object):
             if constants.IN_TEST:
                 # save coverage data that can be later be converted to footprints before reset
                 self.coverage.save()
-            # get_data creates or updates coverage.data with the CoverageData object and
-            # clears counters on the collector but not on the coverage.data object
-            # we make sure to clear coverage.data as well by creating a new one
-            log.debug("before clearing coverage: %s" % self.coverage.collector.data)
+            # get_data creates or updates coverage.data with the CoverageData object and clears counters on the
+            # collector but not on the coverage object
             coverage_object = self.coverage.get_data()
-            if self.should_reset_coverage:
-                self.reset_coverage()
+            log.debug("before clearing coverage: %s" % self.extract_file_covered_lines(coverage_object))
             if not coverage_object:
                 log.info("No Coverage Found")
                 return footprints
 
             for coverage_type, coverage_collector in list(self.coverage_collectors.items()):
                 footprints[coverage_type] = coverage_collector.get_footprints_and_clear(coverage_object)
+
+            if self.should_reset_coverage:
+                self.clear_counters(coverage_object)
         return footprints
 
     def shutdown(self, is_master):
@@ -61,10 +55,13 @@ class CodeCoverageManager(object):
         self.coverage_collectors[coverage_type] = collector
 
     def get_trace_function(self):
-        return self.coverage.collector._installation_trace
+        return self.coverage._collector._installation_trace
 
-    def reset_coverage(self):
-        self.coverage.data = CoverageData(debug=self.coverage.debug)
+    def clear_counters(self, coverage_object):
+        # get_data creates or updates coverage.data with the CoverageData object and
+        # clears counters on the collector but not on the coverage.data object
+        # we make sure to erase coverage.data
+        coverage_object.erase()
 
     def init_coverage(self):
         self.config_data.include = self.config_data.include or []
@@ -74,9 +71,9 @@ class CodeCoverageManager(object):
             # we move workspacepath to include, include python_agent, remove exclude and add "data_suffix=True" so
             # coverage files will be saved each time with a unique suffix so we won't loose coverage after each reset
             self.config_data.include.append("*%s*" % python_agent.__name__)
-            coverage = Coverage(source=None, include=self.config_data.include, omit=None, data_suffix=True, branch=False)
+            coverage = Coverage(source=None, include=self.config_data.include, omit=None, data_suffix=True, branch=False, data_file=None)
         else:
-            coverage = Coverage(source=None, include=self.config_data.include, omit=self.config_data.exclude, data_suffix=True, branch=False)
+            coverage = Coverage(source=None, include=self.config_data.include, omit=self.config_data.exclude, data_suffix=True, branch=False, data_file=None)
         if getattr(coverage, "_warn_no_data", False):
             coverage._warn_no_data = False
         if self.config_data.isOfflineMode:
@@ -103,3 +100,5 @@ class CodeCoverageManager(object):
         except Exception as e:
             log.error("Failed creating report. error=%s" % e)
 
+    def extract_file_covered_lines(self, coverage_object):
+        return {filename: coverage_object.lines(filename) for filename in coverage_object.measured_files()}
