@@ -1,12 +1,11 @@
 import logging
 import threading
 import time
-
 from apscheduler.executors.pool import ProcessPoolExecutor
 from apscheduler.schedulers.background import BackgroundScheduler
+from apscheduler.triggers import interval
 
 from python_agent.common import constants
-from python_agent.packages import interval
 from python_agent.packages.blinker import signal
 from python_agent.test_listener.managers.code_coverage_manager import CodeCoverageManager
 from python_agent.test_listener.queues.footprints_queue import FootprintsQueue
@@ -14,7 +13,6 @@ from python_agent.test_listener.services.footprints_service import FootprintsSer
 from python_agent.test_listener.state_tracker import StateTracker
 from python_agent.test_listener.utils import get_execution_id_from_identifier
 from python_agent.test_listener.utils import get_test_name_from_identifier
-import threading
 
 scheduler_class = BackgroundScheduler
 kwargs = {
@@ -32,11 +30,11 @@ class FootprintsManager(object):
         self.footprints_queue = FootprintsQueue(maxsize=constants.MAX_ITEMS_IN_QUEUE)
         self.code_coverage_manager = CodeCoverageManager(config_data)
         self.watchdog = scheduler_class(**kwargs)
-        self.watchdog.add_job(self.send_all, interval.IntervalTrigger(milliseconds=self.config_data.interval))
+        self.watchdog.add_job(self.send_all, interval.IntervalTrigger(seconds=self.config_data.intervalSeconds))
         self.watchdog.add_job(self.send_current_partial_footprints,
-                              interval.IntervalTrigger(milliseconds=self.config_data.interval))
+                              interval.IntervalTrigger(seconds=self.config_data.intervalSeconds))
         self.watchdog.add_job(self.get_active_execution, interval.IntervalTrigger(
-            milliseconds=constants.ACTIVE_EXECUTION_INTERVAL_IN_MILLISECONDS))
+            seconds=constants.ACTIVE_EXECUTION_INTERVAL_IN_MILLISECONDS / 1000))
         self._is_sending_lock = threading.Lock()
         self.is_getting_footprints_lock = threading.Lock()
         self.has_active_execution = False
@@ -81,8 +79,6 @@ class FootprintsManager(object):
         with self.is_getting_footprints_lock:
             enqueue_coverage(test_identifier)
 
-
-
     def send_all(self, *args, **kwargs):
         self._is_sending_lock.acquire()
         footprint_items = []
